@@ -310,7 +310,8 @@ CryptController::parse_output (GpgME::Data &resolverOutput)
     {
       log_error ("%s:%s: Encrypt requested but no recipient fingerprints",
                  SRCNAME, __func__);
-      gpgol_message_box (m_mail->getWindow (), _("No recipients for encryption selected."),
+      gpgol_message_box (m_mail->getWindow (),
+                         utf8_gettext ("No recipients for encryption selected."),
                          _("GpgOL"), MB_OK);
       TRETURN -2;
     }
@@ -616,7 +617,7 @@ CryptController::resolve_keys ()
 }
 
 int
-CryptController::do_crypto (GpgME::Error &err)
+CryptController::do_crypto (GpgME::Error &err, std::string &r_diag)
 {
   TSTART;
   log_debug ("%s:%s",
@@ -649,7 +650,7 @@ CryptController::do_crypto (GpgME::Error &err)
       m_bodyInput = GpgME::Data(GpgME::Data::null);
     }
 
-  auto ctx = std::shared_ptr<GpgME::Context> (GpgME::Context::createForProtocol(m_proto));
+  auto ctx = GpgME::Context::create(m_proto);
 
   if (!ctx)
     {
@@ -684,6 +685,13 @@ CryptController::do_crypto (GpgME::Error &err)
                      SRCNAME, __func__, result_pair.first.error().asString(),
                      result_pair.second.error().asString());
           err = err1 ? err1 : err2;
+          GpgME::Data log;
+          const auto err3 = ctx->getAuditLog (log,
+                                              GpgME::Context::DiagnosticAuditLog);
+          if (!err3)
+            {
+              r_diag = log.toString();
+            }
           TRETURN -1;
         }
 
@@ -705,6 +713,13 @@ CryptController::do_crypto (GpgME::Error &err)
         {
           log_error ("%s:%s: Signing error %s.",
                      SRCNAME, __func__, sigResult.error().asString());
+          GpgME::Data log;
+          const auto err3 = ctx->getAuditLog (log,
+                                              GpgME::Context::DiagnosticAuditLog);
+          if (!err3)
+            {
+              r_diag = log.toString();
+            }
           TRETURN -1;
         }
       if (err.isCanceled())
@@ -747,6 +762,13 @@ CryptController::do_crypto (GpgME::Error &err)
         {
           log_error ("%s:%s: Encryption error %s.",
                      SRCNAME, __func__, err.asString());
+          GpgME::Data log;
+          const auto err3 = ctx->getAuditLog (log,
+                                              GpgME::Context::DiagnosticAuditLog);
+          if (!err3)
+            {
+              r_diag = log.toString();
+            }
           TRETURN -1;
         }
       if (err.isCanceled())
@@ -767,6 +789,13 @@ CryptController::do_crypto (GpgME::Error &err)
         {
           log_error ("%s:%s: Encryption error %s.",
                      SRCNAME, __func__, err.asString());
+          GpgME::Data log;
+          const auto err3 = ctx->getAuditLog (log,
+                                              GpgME::Context::DiagnosticAuditLog);
+          if (!err3)
+            {
+              r_diag = log.toString();
+            }
           TRETURN -1;
         }
       if (err.isCanceled())
@@ -786,6 +815,13 @@ CryptController::do_crypto (GpgME::Error &err)
         {
           log_error ("%s:%s: Signing error %s.",
                      SRCNAME, __func__, err.asString());
+          GpgME::Data log;
+          const auto err3 = ctx->getAuditLog (log,
+                                              GpgME::Context::DiagnosticAuditLog);
+          if (!err3)
+            {
+              r_diag = log.toString();
+            }
           TRETURN -1;
         }
       if (err.isCanceled())
@@ -878,13 +914,17 @@ create_sign_attach (sink_t sink, protocol_t protocol,
   if (protocol == PROTOCOL_OPENPGP)
     {
       rc = write_string (sink,
-                         "Content-Type: application/pgp-signature\r\n");
+                         "Content-Type: application/pgp-signature;\r\n"
+                         "\tname=\"" OPENPGP_SIG_NAME "\"\r\n"
+                         "Content-Transfer-Encoding: 7Bit\r\n");
     }
   else
     {
       rc = write_string (sink,
                          "Content-Transfer-Encoding: base64\r\n"
-                         "Content-Type: application/pkcs7-signature\r\n");
+                         "Content-Type: application/pkcs7-signature\r\n"
+                         "Content-Disposition: inline;\r\n"
+                         "\tfilename=\"" SMIME_SIG_NAME "\"\r\n");
       /* rc = write_string (sink, */
       /*                    "Content-Type: application/x-pkcs7-signature\r\n" */
       /*                    "\tname=\"smime.p7s\"\r\n" */
@@ -1019,6 +1059,25 @@ CryptController::update_mail_mapi ()
 
   mapi_attach_item_t *att_table = mapi_create_attach_table (message, 0);
 
+  /* When we forward e.g. a crypto mail we have sent the message
+     has a MOSSTEMPL. We need to remove that. T4321 */
+  for (ULONG pos=0; att_table && !att_table[pos].end_of_table; pos++)
+    {
+      if (att_table[pos].attach_type == ATTACHTYPE_MOSSTEMPL)
+        {
+          log_debug ("%s:%s: Found existing moss attachment at "
+                     "pos %i removing it.", SRCNAME, __func__,
+                     att_table[pos].mapipos);
+          if (message->DeleteAttach (att_table[pos].mapipos, 0,
+                                     nullptr, 0) != S_OK)
+            {
+              log_error ("%s:%s: Failed to remove attachment.",
+                         SRCNAME, __func__);
+            }
+
+        }
+    }
+
   // Set up the sink object for our MSOXSMIME attachment.
   struct sink_s sinkmem;
   sink_t sink = &sinkmem;
