@@ -574,6 +574,14 @@ public:
                 validEnough = true;
                 break;
               }
+            if (opt.auto_unstrusted &&
+                uid.validity() == GpgME::UserID::Unknown)
+              {
+                log_debug ("%s:%s: Passing unknown trust key for %s because of option",
+                           SRCNAME, __func__, anonstr (recip.c_str ()));
+                validEnough = true;
+                break;
+              }
           }
         if (!validEnough)
           {
@@ -601,6 +609,15 @@ public:
          fpr */
       const char *primaryFpr = key.primaryFingerprint ();
 
+#if 0
+        {
+          std::stringstream ss;
+          ss << key;
+          log_debug ("%s:%s: Inserting key\n%s",
+                     SRCNAME, __func__, ss.str().c_str ());
+        }
+#endif
+
       for (const auto &sub: key.subkeys())
         {
           const char *subFpr = sub.fingerprint();
@@ -1415,3 +1432,79 @@ KeyCache::getUltimateKeys ()
   gpgrt_lock_unlock (&fpr_map_lock);
   return ret;
 }
+
+/* static */
+bool
+KeyCache::import_pgp_key_data (const GpgME::Data &data)
+{
+  TSTART;
+  if (data.isNull())
+    {
+      STRANGEPOINT;
+      TRETURN false;
+    }
+  auto ctx = GpgME::Context::create(GpgME::OpenPGP);
+
+  if (!ctx)
+    {
+      STRANGEPOINT;
+      TRETURN false;
+    }
+
+  const auto type = data.type();
+
+  if (type != GpgME::Data::PGPKey)
+    {
+      log_debug ("%s:%s: Data does not look like PGP Keys",
+                 SRCNAME, __func__);
+      TRETURN false;
+    }
+  const auto keys = data.toKeys();
+
+  if (keys.empty())
+    {
+      log_debug ("%s:%s: Data does not contain PGP Keys",
+                 SRCNAME, __func__);
+      TRETURN false;
+    }
+
+  if (opt.enable_debug & DBG_DATA)
+    {
+      std::stringstream ss;
+      for (const auto &key: keys)
+        {
+          ss << key << '\n';
+        }
+      log_debug ("Importing keys: %s", ss.str().c_str());
+    }
+  const auto result = ctx->importKeys(data);
+
+  if ((opt.enable_debug & DBG_DATA))
+    {
+      std::stringstream ss;
+      ss << result;
+      log_debug ("%s:%s: Import result: %s details:\n %s",
+                 SRCNAME, __func__, result.error ().asString (),
+                 ss.str().c_str());
+      if (result.error())
+        {
+          GpgME::Data out;
+          if (ctx->getAuditLog(out, GpgME::Context::DiagnosticAuditLog))
+            {
+              log_error ("%s:%s: Failed to get diagnostics",
+                         SRCNAME, __func__);
+            }
+          else
+            {
+              log_debug ("%s:%s: Diagnostics: \n%s\n",
+                         SRCNAME, __func__, out.toString().c_str());
+            }
+        }
+    }
+  else
+    {
+      log_debug ("%s:%s: Import result: %s",
+                 SRCNAME, __func__, result.error ().asString ());
+    }
+  TRETURN !result.error();
+}
