@@ -470,10 +470,10 @@ public:
 
   /** Enable / Disable the window of this mail.
 
-    When value is false the active window will
-    be disabled and the handle stored for a later
-    enable. */
-  void setWindowEnabled_o (bool value);
+    When the window gets disabled the
+    handle is stored for a later enable. */
+  void disableWindow_o ();
+  void enableWindow ();
 
   /** Determine if the mail is an inline response.
 
@@ -601,6 +601,9 @@ public:
   /* Get the storeID for this mail */
   std::string storeID() { return m_store_id; }
 
+  /* Remove encryption permanently. */
+  void decryptPermanently_o ();
+
 private:
   void updateCategories_o ();
   void updateSigstate ();
