@@ -36,12 +36,18 @@
 #include "oomhelp.h"
 #include "cpphelp.h"
 #include "gpgoladdin.h"
+#include "categorymanager.h"
 
 HRESULT
 gpgol_queryInterface (LPUNKNOWN pObj, REFIID riid, LPVOID FAR *ppvObj)
 {
   HRESULT ret = pObj->QueryInterface (riid, ppvObj);
-  if ((opt.enable_debug & DBG_MEMORY) && *ppvObj)
+  if (ret)
+    {
+      log_debug ("%s:%s: QueryInterface failed hr=%#lx",
+                 SRCNAME, __func__, ret);
+    }
+  else if ((opt.enable_debug & DBG_MEMORY) && *ppvObj)
     {
       memdbg_addRef (*ppvObj);
     }
@@ -56,7 +62,12 @@ gpgol_openProperty (LPMAPIPROP obj, ULONG ulPropTag, LPCIID lpiid,
   HRESULT ret = obj->OpenProperty (ulPropTag, lpiid,
                                    ulInterfaceOptions, ulFlags,
                                    lppUnk);
-  if ((opt.enable_debug & DBG_MEMORY) && *lppUnk)
+  if (ret)
+    {
+      log_debug ("%s:%s: OpenProperty failed hr=%#lx",
+                 SRCNAME, __func__, ret);
+    }
+  else if ((opt.enable_debug & DBG_MEMORY) && *lppUnk)
     {
       memdbg_addRef (*lppUnk);
       log_debug ("%s:%s: OpenProperty on %p prop %lx result %p",
@@ -1997,7 +2008,7 @@ add_category (LPDISPATCH mail, const char *category)
   xfree (tmp);
   if (!newstr.empty ())
     {
-      newstr += ", ";
+      newstr += CategoryManager::getSeperator () + std::string (" ");
     }
   newstr += category;
 
@@ -2018,7 +2029,8 @@ remove_category (LPDISPATCH mail, const char *category, bool exactMatch)
   std::vector<std::string> categories;
   std::istringstream f(tmp);
   std::string s;
-  while (std::getline(f, s, ','))
+  const std::string sep = CategoryManager::getSeperator();
+  while (std::getline(f, s, *(sep.c_str())))
     {
       ltrim(s);
       categories.push_back(s);
@@ -2038,7 +2050,8 @@ remove_category (LPDISPATCH mail, const char *category, bool exactMatch)
       return cat.compare (0, categoryStr.size(), categoryStr) == 0;
     }), categories.end ());
   std::string newCategories;
-  join (categories, ", ", newCategories);
+  std::string newsep = sep + " ";
+  join (categories, newsep.c_str (), newCategories);
 
   TRETURN put_oom_string (mail, "Categories", newCategories.c_str ());
 }
@@ -2661,15 +2674,46 @@ log_addins ()
   int count = get_oom_int (addins, "Count");
   for (int i = 1; i <= count; i++)
     {
-      std::string item = std::string ("Item(") + std::to_string (i) + ")";
+      VARIANT aVariant[1];
+      VARIANT rVariant;
 
-      LPDISPATCH addin = get_oom_object (addins, item.c_str ());
+      VariantInit (&rVariant);
+      DISPPARAMS dispparams;
+
+      dispparams.rgvarg = aVariant;
+      dispparams.rgvarg[0].vt = VT_INT;
+      dispparams.rgvarg[0].intVal = i;
+      dispparams.cArgs = 1;
+      dispparams.cNamedArgs = 0;
+
+      /* We need this instead of get_oom_object item(1) as usual becase
+         the item method accepts a string or an int. String would
+         be the ProgID and int is just the index. So Fun. */
+      if (invoke_oom_method_with_parms_type (addins, "Item", &rVariant,
+                                             &dispparams,
+                                             DISPATCH_METHOD |
+                                             DISPATCH_PROPERTYGET))
+        {
+          log_error ("%s:%s: Failed to invoke item func.",
+                     SRCNAME, __func__);
+          continue;
+        }
+
+      if (rVariant.vt != (VT_DISPATCH))
+        {
+          log_error ("%s:%s: Invalid ret val",
+                     SRCNAME, __func__);
+          continue;
+        }
+
+      LPDISPATCH addin = rVariant.pdispVal;
 
       if (!addin)
         {
           TRACEPOINT;
           continue;
         }
+      memdbg_addRef (addin);
       bool connected = get_oom_bool (addin, "Connect");
       if (!connected)
         {
