@@ -56,6 +56,10 @@ typedef enum _gpgol_wmsg_type
   DO_AUTO_SECURE,
   DONT_AUTO_SECURE,
   CONFIG_KEY_DONE,
+  /* External API, keep it stable! */
+  EXT_API_CLOSE = 1301,
+  EXT_API_CLOSE_ALL = 1302,
+  EXT_API_DECRYPT = 1303,
 } gpgol_wmsg_type;
 
 typedef struct
